# grids - The Grids Python Tool for Querying Spatiotemporal Multidimensional Datasets

[![Documentation Status](https://readthedocs.org/projects/tsgrids/badge/?version=latest)](https://grids.rileyhales.com/en/latest/?badge=latest)
[![GitHub repo size](https://img.shields.io/github/repo-size/rileyhales/grids?style=plastic)](https://github.com/rileyhales/grids)
     
A python tool for extracting time series subsets from multi-dimensional data arrays developed by Riley Hales as part of a Master's Thesis in Civil and Environmental Engineering at Brigham Young University.

## Citing `grids`
If you use this code, please cite the following academic journal article and source code doi's:
- https://doi.org/10.3390/w13152066
- https://doi.org/10.5281/zenodo.5225437

## Documentation and Demos
[Read documentation on ReadTheDocs](https://grids.rileyhales.com)

[Use a live demo notebook on Google Collaboratory](https://gist.github.com/rileyhales/79761303df16127e0195e11425fc2d9d)
